#! /usr/bin/env python
# -*- coding: utf-8 -*-
"""Initialization for berhoel python namespace packages.
"""

__date__ = "2021/12/11 17:51:35 hoel"
__author__ = "Berthold Höllmann"
__copyright__ = "Copyright © 2018 by Berthold Höllmann"
__credits__ = ["Berthold Höllmann"]
__maintainer__ = "Berthold Höllmann"
__email__ = "berhoel@gmail.com"

__import__("pkg_resources").declare_namespace(__name__)


# Local Variables:
# mode: python
# compile-command: "python ../setup.py test"
# time-stamp-pattern: "30/__date__ = \"%:y/%02m/%02d %02H:%02M:%02S %u\""
# End:
